@@ -1,24 +1,32 @@
+from orm.constants import CASCADE, RESTRICT, SET_NULL
 from orm.exceptions import MultipleMatches, NoMatch
 from orm.fields import (
     JSON,
+    URL,
     UUID,
     BigInteger,
     Boolean,
     Date,
     DateTime,
     Decimal,
+    Email,
     Enum,
     Float,
     ForeignKey,
     Integer,
+    IPAddress,
+    OneToOne,
     String,
     Text,
     Time,
 )
 from orm.models import Model, ModelRegistry
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 __all__ = [
+    "CASCADE",
+    "RESTRICT",
+    "SET_NULL",
     "NoMatch",
     "MultipleMatches",
     "BigInteger",
@@ -26,15 +34,19 @@ __all__ = [
     "Date",
     "DateTime",
     "Decimal",
+    "Email",
     "Enum",
     "Float",
+    "ForeignKey",
     "Integer",
+    "IPAddress",
     "JSON",
+    "OneToOne",
     "String",
     "Text",
     "Time",
+    "URL",
     "UUID",
-    "ForeignKey",
     "Model",
     "ModelRegistry",
 ]
