@@ -3,7 +3,7 @@ import typing
 import sqlalchemy
 import typesystem
 
-from orm.sqlalchemy_fields import GUID
+from orm.sqlalchemy_fields import GUID, GenericIP
 
 
 class ModelField:
@@ -137,9 +137,12 @@ class ForeignKey(ModelField):
         def validate(self, value):
             return value.pk
 
-    def __init__(self, to, allow_null: bool = False):
+    def __init__(
+        self, to, allow_null: bool = False, on_delete: typing.Optional[str] = None
+    ):
         super().__init__(allow_null=allow_null)
         self.to = to
+        self.on_delete = on_delete
 
     @property
     def target(self):
@@ -159,7 +162,9 @@ class ForeignKey(ModelField):
 
         column_type = to_field.get_column_type()
         constraints = [
-            sqlalchemy.schema.ForeignKey(f"{target.tablename}.{target.pkname}")
+            sqlalchemy.schema.ForeignKey(
+                f"{target.tablename}.{target.pkname}", ondelete=self.on_delete
+            )
         ]
         return sqlalchemy.Column(
             name,
@@ -175,6 +180,27 @@ class ForeignKey(ModelField):
         return target(pk=value)
 
 
+class OneToOne(ForeignKey):
+    def get_column(self, name: str) -> sqlalchemy.Column:
+        target = self.target
+        to_field = target.fields[target.pkname]
+
+        column_type = to_field.get_column_type()
+        constraints = [
+            sqlalchemy.schema.ForeignKey(
+                f"{target.tablename}.{target.pkname}", ondelete=self.on_delete
+            ),
+        ]
+
+        return sqlalchemy.Column(
+            name,
+            column_type,
+            *constraints,
+            nullable=self.allow_null,
+            unique=True,
+        )
+
+
 class Enum(ModelField):
     def __init__(self, enum, **kwargs):
         super().__init__(**kwargs)
@@ -208,3 +234,27 @@ class UUID(ModelField):
 
     def get_column_type(self):
         return GUID()
+
+
+class Email(String):
+    def get_validator(self, **kwargs) -> typesystem.Field:
+        return typesystem.Email(**kwargs)
+
+    def get_column_type(self):
+        return sqlalchemy.String(length=self.validator.max_length)
+
+
+class IPAddress(ModelField):
+    def get_validator(self, **kwargs) -> typesystem.Field:
+        return typesystem.IPAddress(**kwargs)
+
+    def get_column_type(self):
+        return GenericIP()
+
+
+class URL(String):
+    def get_validator(self, **kwargs) -> typesystem.Field:
+        return typesystem.URL(**kwargs)
+
+    def get_column_type(self):
+        return sqlalchemy.String(length=self.validator.max_length)
